from tkinter import *
from tkinter.filedialog import askdirectory
import os
import shutil

class Commands():

	def __init__(self):
		self.dir_name = "."

	def get_path(self):
		self.dir_name = askdirectory()

	def create(self , packname, path):
		if not path :
			self.get_path()
		packname , run_name = packname.split(':')
		os.makedirs(f"{self.dir_name}/{packname}/{packname}")
		files=os.listdir("./dep")
		for fname in files:
			shutil.copy2(os.path.join("./dep",fname),f"{self.dir_name}/{packname}/" )
		with open(f"{self.dir_name}/{packname}/{packname}/__init__.py" ,"w+") as f :
				f.write(" ")				
		with open(f"{self.dir_name}/{packname}/{packname}/{run_name}.py" ,"w+") as f :
				f.write("#GETTING STARTED")				


import sys
from tkinter import *
from tkinter import ttk
from bundlesnake.Commands import Commands

root = Tk()
root['bg'] ="#222222"
root.title('Get Package')
root.geometry('400x500')

Label(text="Package Name :",bg ="#222222",fg ="#fff").place(relx = 0.1, rely = 0.2, relwidth = 0.8 , relheight = 0.1)
packname = ttk.Entry(font = 12)
packname.place(relx = 0.1, rely = 0.3 , relwidth = 0.8 , relheight = 0.1)
submit = Button(text='Create',bg ="#222222",fg ="#fff" ,command =lambda :commands.create(packname.get(), path = 0 )).place(relx = 0.1, rely = 0.5 , relwidth = 0.8 , relheight = 0.1)



if __name__ == "__main__":
    commands = Commands()
    if len(sys.argv) > 1 : commands.create(sys.argv[1],path = 1)
    else:
        root.mainloop()


